Blog

Struct Blog 

pub struct Blog {
Show 13 fields pub custom_meta_data: Option<String>, pub description: Option<String>, pub id: Option<String>, pub kind: Option<String>, pub locale: Option<BlogLocale>, pub name: Option<String>, pub pages: Option<BlogPages>, pub posts: Option<BlogPosts>, pub published: Option<String>, pub self_link: Option<String>, pub status: Option<String>, pub updated: Option<String>, pub url: Option<String>,
}
There is no detailed description.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

custom_meta_data: Option<String>

The JSON custom meta-data for the Blog.

description: Option<String>

The description of this blog. This is displayed underneath the title.

id: Option<String>

The identifier for this resource.

kind: Option<String>

The kind of this entry. Always blogger#blog.

locale: Option<BlogLocale>

The locale this Blog is set to.

name: Option<String>

The name of this blog. This is displayed as the title.

pages: Option<BlogPages>

The container of pages in this blog.

posts: Option<BlogPosts>

The container of posts in this blog.

published: Option<String>

RFC 3339 date-time when this blog was published.

self_link: Option<String>

The API REST URL to fetch this resource from.

status: Option<String>

The status of the blog.

updated: Option<String>

RFC 3339 date-time when this blog was last updated.

url: Option<String>

The URL where this blog is published.