pub struct BlogList {
pub blog_user_infos: Option<Vec<BlogUserInfo>>,
pub items: Option<Vec<Blog>>,
pub kind: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list by user blogs (response)
Fields
blog_user_infos: Option<Vec<BlogUserInfo>>Admin level list of blog per-user information.
items: Option<Vec<Blog>>The list of Blogs this user has Authorship or Admin rights over.
kind: Option<String>The kind of this entity. Always blogger#blogList.