pub struct BlogPages {
pub self_link: Option<String>,
pub total_items: Option<i32>,
}Expand description
The container of pages in this blog.
This type is not used in any activity, and only used as part of another schema.
Fields
self_link: Option<String>The URL of the container for pages in this blog.
total_items: Option<i32>The count of pages in this blog.