pub struct BlogPerUserInfo {
pub blog_id: Option<String>,
pub has_admin_access: Option<bool>,
pub kind: Option<String>,
pub photos_album_key: Option<String>,
pub role: Option<String>,
pub user_id: Option<String>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
blog_id: Option<String>ID of the Blog resource.
has_admin_access: Option<bool>True if the user has Admin level access to the blog.
kind: Option<String>The kind of this entity. Always blogger#blogPerUserInfo.
photos_album_key: Option<String>The Photo Album Key for the user when adding photos to the blog.
role: Option<String>Access permissions that the user has for the blog (ADMIN, AUTHOR, or READER).
user_id: Option<String>ID of the User.