pub struct BlogPosts {
pub items: Option<Vec<Post>>,
pub self_link: Option<String>,
pub total_items: Option<i32>,
}Expand description
The container of posts in this blog.
This type is not used in any activity, and only used as part of another schema.
Fields
items: Option<Vec<Post>>The List of Posts for this Blog.
self_link: Option<String>The URL of the container for posts in this blog.
total_items: Option<i32>The count of posts in this blog.