Struct google_blogger3::api::Comment [−][src]
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- approve comments (response)
- delete comments (none)
- get comments (response)
- list comments (none)
- list by blog comments (none)
- mark as spam comments (response)
- remove content comments (response)
Fields
The author of this Comment.
blog: Option<CommentBlog>Data about the blog containing this comment.
content: Option<String>The actual content of the comment. May include HTML markup.
id: Option<String>The identifier for this resource.
in_reply_to: Option<CommentInReplyTo>Data about the comment this is in reply to.
kind: Option<String>The kind of this entry. Always blogger#comment.
post: Option<CommentPost>Data about the post containing this comment.
published: Option<String>RFC 3339 date-time when this comment was published.
self_link: Option<String>The API REST URL to fetch this resource from.
status: Option<String>The status of the comment (only populated for admin users).
updated: Option<String>RFC 3339 date-time when this comment was last updated.