pub struct PageList {
pub etag: Option<String>,
pub items: Option<Vec<Page>>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list pages (response)
Fields
etag: Option<String>Etag of the response.
items: Option<Vec<Page>>The list of Pages for a Blog.
kind: Option<String>The kind of this entity. Always blogger#pageList.
next_page_token: Option<String>Pagination token to fetch the next page, if one exists.