pub struct PostBlog {
pub id: Option<String>,
}Expand description
Data about the blog containing this Post.
This type is not used in any activity, and only used as part of another schema.
Fields
id: Option<String>The identifier of the Blog that contains this Post.