pub struct PostList {
pub etag: Option<String>,
pub items: Option<Vec<Post>>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub prev_page_token: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list posts (response)
- search posts (response)
Fields
etag: Option<String>Etag of the response.
items: Option<Vec<Post>>The list of Posts for this Blog.
kind: Option<String>The kind of this entity. Always blogger#postList.
next_page_token: Option<String>Pagination token to fetch the next page, if one exists.
prev_page_token: Option<String>Pagination token to fetch the previous page, if one exists.