pub struct PostPerUserInfo {
pub blog_id: Option<String>,
pub has_edit_access: Option<bool>,
pub kind: Option<String>,
pub post_id: Option<String>,
pub user_id: Option<String>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
blog_id: Option<String>ID of the Blog that the post resource belongs to.
has_edit_access: Option<bool>True if the user has Author level access to the post.
kind: Option<String>The kind of this entity. Always blogger#postPerUserInfo.
post_id: Option<String>ID of the Post resource.
user_id: Option<String>ID of the User.