pub struct PostUserInfo {
pub kind: Option<String>,
pub post: Option<Post>,
pub post_user_info: Option<PostPerUserInfo>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get post user infos (response)
- list post user infos (none)
Fields
kind: Option<String>The kind of this entity. Always blogger#postUserInfo.
post: Option<Post>The Post resource.
post_user_info: Option<PostPerUserInfo>Information about a User for the Post.