pub struct PostUserInfosList {
pub items: Option<Vec<PostUserInfo>>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list post user infos (response)
Fields
items: Option<Vec<PostUserInfo>>The list of Posts with User information for the post, for this Blog.
kind: Option<String>The kind of this entity. Always blogger#postList.
next_page_token: Option<String>Pagination token to fetch the next page, if one exists.