User

Struct User 

pub struct User {
    pub about: Option<String>,
    pub blogs: Option<UserBlogs>,
    pub created: Option<String>,
    pub display_name: Option<String>,
    pub id: Option<String>,
    pub kind: Option<String>,
    pub locale: Option<UserLocale>,
    pub self_link: Option<String>,
    pub url: Option<String>,
}
There is no detailed description.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

about: Option<String>

Profile summary information.

blogs: Option<UserBlogs>

The container of blogs for this user.

created: Option<String>

The timestamp of when this profile was created, in seconds since epoch.

display_name: Option<String>

The display name.

id: Option<String>

The identifier for this User.

kind: Option<String>

The kind of this entity. Always blogger#user.

locale: Option<UserLocale>

This user’s locale

self_link: Option<String>

The API REST URL to fetch this resource from.

url: Option<String>

The user’s profile page.